package com.aitrainer.api.test

import com.aitrainer.api.controller.ExerciseController
import com.aitrainer.api.controller.TrackingController
import com.aitrainer.api.model.Exercises
import com.aitrainer.api.model.Tracking
import com.aitrainer.api.repository.ExercisesRepository
import com.aitrainer.api.repository.TrackingRepository
import org.junit.jupiter.api.Test
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.HttpStatus
import org.springframework.http.ResponseEntity
import kotlin.test.assertEquals
import kotlin.test.assertTrue

@SpringBootTest
class TrackingTest {

    @Autowired
    private lateinit var trackingRepository: TrackingRepository


    @Test
    fun testInsert() {
        var tracking = Tracking(
            customerId = 90,
            dateAdd = "2021-02-04 23:40:00",
            event = "Home"
        )
        val trackingNew = trackingRepository.save(tracking)
        assertEquals(trackingNew.event, "Home")
        trackingRepository.delete(tracking)

        tracking = Tracking(
            customerId = 90,
            dateAdd = "2021-02-04 23:42:00",
            event = "SalesPage",
            eventValue = 12.0.toString(),
            platform = "iOS",
            version = "1.1.5"
        )

        val controller = TrackingController(trackingRepository)
        val response = controller.createNewTracking(tracking)
        assertEquals(response.statusCode, HttpStatus.OK)
        assertTrue(response.body is Tracking )
        val trackingResponse = response.body
        assertEquals(trackingResponse!!.event, "SalesPage")
        assertEquals(trackingResponse.eventValue, "12.0")
        assertEquals(trackingResponse.version, "1.1.5")
        trackingRepository.delete(trackingResponse)
    }

}